@@ -10,6 +10,13 @@ pub(crate) mod normalization;
 
 use self::props::*;
 
+/// Current Unicode version.
+pub const UNICODE_VERSION: UnicodeVersion = UnicodeVersion {
+    major: 13,
+    minor: 0,
+    update: 0,
+};
+
 /// A Unicode code point.
 /// The valid code point ranges are 0x0 to 0x10FFFF.
 #[derive(Clone, Copy)]
@@ -34,6 +41,20 @@ impl CodePoint {
     }
 }
 
+/// A struct for contain Unicode version.
+#[derive(Debug, PartialEq, PartialOrd, Clone, Copy)]
+pub struct UnicodeVersion {
+    pub major: u32,
+    pub minor: u32,
+    pub update: u32,
+}
+
+impl ToString for UnicodeVersion {
+    fn to_string(&self) -> String {
+        format!("{}.{}.{}", self.major, self.minor, self.update)
+    }
+}
+
 /// Trait that convert type to `CodePoint`.
 ///
 /// The source type should always in valid code point range.
@@ -108,6 +129,8 @@ pub trait Ucd {
     fn blk(&self) -> Blk;
     /// Get the Unicode Script(sc) property.
     fn sc(&self) -> Sc;
+    /// Get the Unicode Age(age) property.
+    fn age(&self) -> Age;
 
     fn math(&self) -> bool;
     fn alpha(&self) -> bool;
@@ -308,6 +331,10 @@ impl Ucd for CodePoint {
         ucd::sc::sc(self.code_point)
     }
 
+    fn age(&self) -> Age {
+        ucd::age::age(self.code_point)
+    }
+
     fn math(&self) -> bool {
         ucd::derived_props::math(self.code_point)
     }
@@ -538,6 +565,10 @@ impl Ucd for char {
         ucd::sc::sc(*self as u32)
     }
 
+    fn age(&self) -> Age {
+        ucd::age::age(*self as u32)
+    }
+
     fn math(&self) -> bool {
         ucd::derived_props::math(*self as u32)
     }
@@ -673,6 +704,19 @@ impl<'a> Iterator for BreakGraphemes<'a> {
             }
             // Do not break within emoji modifier sequences or emoji zwj sequences.
             // GB11: \p{ExtPict} Extend* ZWJ × \p{ExtPict}
+            if curr_ch.1.ext_pict()
+                && (next_ch.1.ext_pict())
+            {
+                curr = next;
+                // next = iter.next();
+                break;
+            }
+            if curr_ch.1.ext_pict()
+                && (!next_ch.1.ext_pict())
+            {
+                curr = next;
+                break;
+            }
             if curr_ch.1.ext_pict() {
                 in_ext_pict = true;
                 curr = next;
@@ -714,7 +758,8 @@ impl<'a> Iterator for BreakGraphemes<'a> {
             // if there is an odd number of RI characters before the break point.
             // GB12:   sot (RI RI)* RI × RI
             // GB13: [^RI] (RI RI)* RI × RI
-            if _ri_count % 2 != 0 {
+            if (curr_ch.1.gcb() == Gcb::RI && next_ch.1.gcb() == Gcb::RI)
+                    && _ri_count % 2 != 0 {
                 curr = next;
                 next = iter.next();
                 continue;
